@@ -223,7 +223,7 @@ class Enumeration(object):
         return self.reverseLookup[value]
 
 
-CONSTANT_RE = re.compile('^([\w\s,]+)=', re.M)
+CONSTANT_RE = re.compile(r'^([\w\s,]+)=', re.M)
 
 EXCLUDED_ATTRS = ['__builtins__', '__doc__', '__name__', '__file__', '__path__',
                   '__module__', '__all__', '__cached__', '__loader__', '__package__',
